@@ -2,6 +2,8 @@ get.urls <- function(partial.url) {
   con <- file(paste(partial.url,"list.txt",sep="/"),open="r")
   lines <- readLines(con)
   close(con)
+  if ( lines[1] != "#jvmr.jar.list" ) stop("unexpected header.")
+  lines <- lines[-1]
   paste(partial.url,lines,sep="/")
 }
 
@@ -11,9 +13,14 @@ download.jars <- function(path) {
     dir.create(tmpDir,recursive=TRUE,showWarnings=FALSE)
     cwd <- getwd()
     setwd(tmpDir)
-    jarURLs <- tryCatch(get.urls(paste("http://dahl.byu.edu/software/jvmr/alljars/",jvmr.version,sep="")),
+    download.sites <- c("http://dahl.byu.edu/software/jvmr/alljars/","http://ddahl.org/alljars/","file:///home/dahl/docs/devel/website-professional/html/software/jvmr/alljars/")
+    jarURLs <- tryCatch(get.urls(paste(download.sites[1],jvmr.version,"/bin",sep="")),
       error = function(e) {
-        get.urls(paste("http://ddahl.org/alljars/",jvmr.version,sep=""))
+        tryCatch(get.urls(paste(download.sites[2],jvmr.version,"/bin",sep="")),
+          error = function(e) {
+            get.urls(paste(download.sites[3],jvmr.version,"/bin",sep=""))
+          }
+        )
       }
     )
     for ( jarURL in jarURLs ) {
